@@ -1,18 +1,24 @@
 from abc import ABC, abstractmethod
-from typing import Dict, List
+from typing import Dict, List, Literal
 from decimal import Decimal
 import asyncio
 
-from aiolimiter import AsyncLimiter
-
+from decimal import ROUND_HALF_UP, ROUND_CEILING, ROUND_FLOOR
+from nexustrader.base.oms import OrderManagementSystem
 from nexustrader.base.ws_client import WSClient
 from nexustrader.base.api_client import ApiClient
 from nexustrader.base.exchange import ExchangeManager
-from nexustrader.schema import Order, BaseMarket, Kline, Position, Balance
+from nexustrader.schema import (
+    Order,
+    BaseMarket,
+    Position,
+    Balance,
+    KlineList,
+    Ticker,
+)
 from nexustrader.constants import ExchangeType, AccountType
-from nexustrader.core.log import SpdLog
 from nexustrader.core.cache import AsyncCache
-from nexustrader.core.entity import RateLimit, TaskManager
+from nexustrader.core.entity import TaskManager
 from nexustrader.error import OrderError
 from nexustrader.constants import (
     OrderSide,
@@ -20,11 +26,10 @@ from nexustrader.constants import (
     TimeInForce,
     PositionSide,
     KlineInterval,
-    TriggerType,
     BookLevel,
     OrderStatus,
 )
-from nexustrader.core.nautilius_core import LiveClock, MessageBus, UUID4
+from nexustrader.core.nautilius_core import LiveClock, MessageBus, UUID4, Logger
 
 
 class ApiProxy:
@@ -40,6 +45,10 @@ class ApiProxy:
         if not callable(api_method):
             return api_method
 
+        # check whether the method is async
+        if not asyncio.iscoroutinefunction(api_method):
+            return api_method
+
         def sync_wrapper(*args, **kwargs):
             return self._task_manager.run_sync(api_method(*args, **kwargs))
 
@@ -55,13 +64,11 @@ class PublicConnector(ABC):
         exchange_id: ExchangeType,
         ws_client: WSClient,
         msgbus: MessageBus,
+        clock: LiveClock,
         api_client: ApiClient,
         task_manager: TaskManager,
-        rate_limit: RateLimit | None = None,
     ):
-        self._log = SpdLog.get_logger(
-            name=type(self).__name__, level="DEBUG", flush=True
-        )
+        self._log = Logger(name=type(self).__name__)
         self._account_type = account_type
         self._market = market
         self._market_id = market_id
@@ -69,14 +76,9 @@ class PublicConnector(ABC):
         self._ws_client = ws_client
         self._msgbus = msgbus
         self._api_client = api_client
-        self._clock = LiveClock()
+        self._clock = clock
         self._task_manager = task_manager
 
-        if rate_limit:
-            self._limiter = AsyncLimiter(rate_limit.max_rate, rate_limit.time_period)
-        else:
-            self._limiter = None
-
     @property
     def account_type(self):
         return self._account_type
@@ -89,10 +91,37 @@ class PublicConnector(ABC):
         limit: int | None = None,
         start_time: int | None = None,
         end_time: int | None = None,
-    ) -> list[Kline]:
+    ) -> KlineList:
         """Request klines"""
         pass
 
+    @abstractmethod
+    def request_ticker(
+        self,
+        symbol: str,
+    ) -> Ticker:
+        """Request 24hr ticker data"""
+        pass
+
+    @abstractmethod
+    def request_all_tickers(
+        self,
+    ) -> Dict[str, Ticker]:
+        """Request 24hr ticker data for multiple symbols"""
+        pass
+
+    @abstractmethod
+    def request_index_klines(
+        self,
+        symbol: str,
+        interval: KlineInterval,
+        limit: int | None = None,
+        start_time: int | None = None,
+        end_time: int | None = None,
+    ) -> KlineList:
+        """Request index klines"""
+        pass
+
     @abstractmethod
     async def subscribe_trade(self, symbol: str | List[str]):
         """Subscribe to the trade data"""
@@ -139,33 +168,17 @@ class PrivateConnector(ABC):
         self,
         account_type: AccountType,
         market: Dict[str, BaseMarket],
-        market_id: Dict[str, str],
-        exchange_id: ExchangeType,
-        ws_client: WSClient,
         api_client: ApiClient,
-        msgbus: MessageBus,
-        cache: AsyncCache,
         task_manager: TaskManager,
-        rate_limit: RateLimit | None = None,
+        oms: OrderManagementSystem,
     ):
-        self._log = SpdLog.get_logger(
-            name=type(self).__name__, level="DEBUG", flush=True
-        )
+        self._log = Logger(name=type(self).__name__)
         self._account_type = account_type
         self._market = market
-        self._market_id = market_id
-        self._exchange_id = exchange_id
-        self._ws_client = ws_client
         self._api_client = api_client
-        self._cache = cache
-        self._clock = LiveClock()
+        self._oms = oms
         self._task_manager = task_manager
-        self._msgbus: MessageBus = msgbus
         self._api_proxy = ApiProxy(self._api_client, self._task_manager)
-        if rate_limit:
-            self._limiter = AsyncLimiter(rate_limit.max_rate, rate_limit.time_period)
-        else:
-            self._limiter = None
 
     @property
     def account_type(self):
@@ -175,97 +188,49 @@ class PrivateConnector(ABC):
     def api(self):
         return self._api_proxy
 
-    @abstractmethod
-    async def _init_account_balance(self):
-        """Initialize the account balance"""
-        pass
-
-    @abstractmethod
-    async def _init_position(self):
-        """Initialize the position"""
-        pass
-
-    @abstractmethod
-    async def create_stop_loss_order(
+    def _price_to_precision(
         self,
         symbol: str,
-        side: OrderSide,
-        type: OrderType,
-        amount: Decimal,
-        trigger_price: Decimal,
-        trigger_type: TriggerType = TriggerType.LAST_PRICE,
-        price: Decimal | None = None,
-        time_in_force: TimeInForce = TimeInForce.GTC,
-        position_side: PositionSide | None = None,
-        **kwargs,
-    ) -> Order:
-        """Create a stop loss order"""
-        pass
+        price: float,
+        mode: Literal["round", "ceil", "floor"] = "round",
+    ) -> Decimal:
+        """
+        Convert the price to the precision of the market
+        """
+        market = self._market[symbol]
+        price: Decimal = Decimal(str(price))
 
-    @abstractmethod
-    async def create_take_profit_order(
-        self,
-        symbol: str,
-        side: OrderSide,
-        type: OrderType,
-        amount: Decimal,
-        trigger_price: Decimal,
-        trigger_type: TriggerType = TriggerType.LAST_PRICE,
-        price: Decimal | None = None,
-        time_in_force: TimeInForce = TimeInForce.GTC,
-        position_side: PositionSide | None = None,
-        **kwargs,
-    ) -> Order:
-        """Create a take profit order"""
-        pass
+        decimal = market.precision.price
 
-    @abstractmethod
-    async def create_order(
-        self,
-        symbol: str,
-        side: OrderSide,
-        type: OrderType,
-        amount: Decimal,
-        price: Decimal,
-        time_in_force: TimeInForce,
-        position_side: PositionSide,
-        **kwargs,
-    ) -> Order:
-        """Create an order"""
-        pass
+        if decimal >= 1:
+            exp = Decimal(int(decimal))
+            precision_decimal = Decimal("1")
+        else:
+            exp = Decimal("1")
+            precision_decimal = Decimal(str(decimal))
 
-    @abstractmethod
-    async def cancel_order(self, symbol: str, order_id: str, **kwargs) -> Order:
-        """Cancel an order"""
-        pass
-
-    @abstractmethod
-    async def modify_order(
-        self,
-        symbol: str,
-        order_id: str,
-        side: OrderSide | None = None,
-        price: Decimal | None = None,
-        amount: Decimal | None = None,
-        **kwargs,
-    ) -> Order:
-        """Modify an order"""
-        pass
-
-    @abstractmethod
-    async def cancel_all_orders(self, symbol: str) -> bool:
-        """Cancel all orders"""
-        pass
+        if mode == "round":
+            format_price = (price / exp).quantize(
+                precision_decimal, rounding=ROUND_HALF_UP
+            ) * exp
+        elif mode == "ceil":
+            format_price = (price / exp).quantize(
+                precision_decimal, rounding=ROUND_CEILING
+            ) * exp
+        elif mode == "floor":
+            format_price = (price / exp).quantize(
+                precision_decimal, rounding=ROUND_FLOOR
+            ) * exp
+        return format_price
 
     @abstractmethod
     async def connect(self):
         """Connect to the exchange"""
-        await self._init_account_balance()
-        await self._init_position()
+        pass
 
     async def disconnect(self):
         """Disconnect from the exchange"""
-        self._ws_client.disconnect()
+        self._oms._ws_client.disconnect()
         await self._api_client.close_session()
 
 
@@ -284,6 +249,7 @@ class MockLinearConnector:
         account_type: AccountType,  # LINEAR_MOCK
         exchange: ExchangeManager,
         msgbus: MessageBus,
+        clock: LiveClock,
         cache: AsyncCache,
         task_manager: TaskManager,
         overwrite_balance: bool = False,
@@ -305,12 +271,10 @@ class MockLinearConnector:
         self._overwrite_position = overwrite_position
         self._quote_currency = quote_currency
         self._update_interval = update_interval
-        self._clock = LiveClock()
+        self._clock = clock
         self._task_manager = task_manager
         self._leverage = leverage
-        self._log = SpdLog.get_logger(
-            name=type(self).__name__, level="DEBUG", flush=True
-        )
+        self._log = Logger(name=type(self).__name__)
 
     async def _init_position(self):
         for _, position in self._cache._get_all_positions_from_db(
@@ -334,6 +298,14 @@ class MockLinearConnector:
         self._cache._apply_balance(self._account_type, balances)
         await self._cache.sync_balances()
 
+    async def cancel_order(self, symbol: str, order_id: str, **kwargs) -> Order:
+        """Cancel an order"""
+        pass
+
+    async def cancel_all_orders(self, symbol: str) -> bool:
+        """Cancel all orders"""
+        pass
+
     async def create_order(
         self,
         symbol: str,
@@ -345,6 +317,12 @@ class MockLinearConnector:
         **kwargs,
     ) -> Order:
         try:
+            if amount <= 0:
+                raise OrderError(f"Invalid order amount {amount}")
+
+            if price is not None and price <= 0:
+                raise OrderError(f"Invalid order price {price}")
+
             market = self._market.get(symbol)
             if not market:
                 raise OrderError(f"Symbol {symbol} not found")
@@ -484,7 +462,7 @@ class MockLinearConnector:
         ).items():
             book = self._cache.bookl1(symbol)
             if not book:
-                self._log.warn(
+                self._log.warning(
                     f"Please subscribe to the `bookl1` data for {symbol} or data not ready"
                 )
                 continue
@@ -497,7 +475,7 @@ class MockLinearConnector:
         ).items():
             book = self._cache.bookl1(symbol)
             if not book:
-                self._log.warn(
+                self._log.warning(
                     f"Please subscribe to the `bookl1` data for {symbol} or data not ready"
                 )
                 return
