@@ -6,9 +6,8 @@ from decimal import Decimal
 from decimal import ROUND_HALF_UP, ROUND_CEILING, ROUND_FLOOR
 
 from nexustrader.schema import Order, BaseMarket
-from nexustrader.core.log import SpdLog
 from nexustrader.core.entity import TaskManager
-from nexustrader.core.nautilius_core import MessageBus, LiveClock
+from nexustrader.core.nautilius_core import MessageBus, LiveClock, Logger
 from nexustrader.core.cache import AsyncCache
 from nexustrader.core.registry import OrderRegistry
 from nexustrader.constants import (
@@ -29,6 +28,7 @@ from nexustrader.schema import (
     ModifyOrderSubmit,
     TWAPOrderSubmit,
     CancelTWAPOrderSubmit,
+    BatchOrderSubmit,
 )
 from nexustrader.base.connector import PrivateConnector
 
@@ -39,21 +39,22 @@ class ExecutionManagementSystem(ABC):
         market: Dict[str, BaseMarket],
         cache: AsyncCache,
         msgbus: MessageBus,
+        clock: LiveClock,
         task_manager: TaskManager,
         registry: OrderRegistry,
         is_mock: bool = False,
     ):
-        self._log = SpdLog.get_logger(
-            name=type(self).__name__, level="DEBUG", flush=True
-        )
+        self._log = Logger(name=type(self).__name__)
 
         self._market = market
         self._cache = cache
         self._msgbus = msgbus
         self._task_manager = task_manager
         self._registry = registry
-        self._clock = LiveClock()
-        self._order_submit_queues: Dict[AccountType, asyncio.Queue[OrderSubmit]] = {}
+        self._clock = clock
+        self._order_submit_queues: Dict[
+            AccountType, asyncio.Queue[(OrderSubmit, SubmitType)]
+        ] = {}
         self._private_connectors: Dict[AccountType, PrivateConnector] | None = None
         self._is_mock = is_mock
 
@@ -147,7 +148,10 @@ class ExecutionManagementSystem(ABC):
 
     @abstractmethod
     def _submit_order(
-        self, order: OrderSubmit, account_type: AccountType | None = None
+        self,
+        order: OrderSubmit | List[OrderSubmit],
+        submit_type: SubmitType,
+        account_type: AccountType | None = None,
     ):
         """
         Submit an order
@@ -162,7 +166,10 @@ class ExecutionManagementSystem(ABC):
         """
         order_id = self._registry.get_order_id(order_submit.uuid)
         if order_id:
-            order: Order = await self._private_connectors[account_type].modify_order(
+            order: Order = await self._private_connectors[
+                account_type
+            ]._oms.modify_order(
+                uuid=order_submit.uuid,
                 symbol=order_submit.symbol,
                 order_id=order_id,
                 price=order_submit.price,
@@ -170,7 +177,6 @@ class ExecutionManagementSystem(ABC):
                 side=order_submit.side,
                 **order_submit.kwargs,
             )
-            order.uuid = order_submit.uuid
             if order.success:
                 self._cache._order_status_update(order)
                 self._msgbus.send(endpoint="pending", msg=order)
@@ -188,7 +194,7 @@ class ExecutionManagementSystem(ABC):
         """
         Cancel all orders
         """
-        await self._private_connectors[account_type].cancel_all_orders(
+        await self._private_connectors[account_type]._oms.cancel_all_orders(
             order_submit.symbol
         )
 
@@ -200,17 +206,19 @@ class ExecutionManagementSystem(ABC):
         """
         order_id = self._registry.get_order_id(order_submit.uuid)
         if order_id:
-            order: Order = await self._private_connectors[account_type].cancel_order(
+            order: Order = await self._private_connectors[
+                account_type
+            ]._oms.cancel_order(
+                uuid=order_submit.uuid,
                 symbol=order_submit.symbol,
                 order_id=order_id,
                 **order_submit.kwargs,
             )
-            order.uuid = order_submit.uuid
             if order.success:
                 self._cache._order_status_update(order)  # SOME STATUS -> CANCELING
                 self._msgbus.send(endpoint="canceling", msg=order)
             else:
-                # self._cache._order_status_update(order) # SOME STATUS -> FAILED
+                self._cache._order_status_update(order)  # SOME STATUS -> FAILED
                 self._msgbus.send(endpoint="cancel_failed", msg=order)
             return order
         else:
@@ -218,23 +226,43 @@ class ExecutionManagementSystem(ABC):
                 f"Order ID not found for UUID: {order_submit.uuid}, The order may already be canceled or filled or not exist"
             )
 
+    async def _cancel_order_ws(
+        self, order_submit: CancelOrderSubmit, account_type: AccountType
+    ):
+        """
+        Cancel an order
+        """
+        order_id = self._registry.get_order_id(order_submit.uuid)
+        if order_id:
+            await self._private_connectors[account_type]._oms.cancel_order_ws(
+                uuid=order_submit.uuid,
+                symbol=order_submit.symbol,
+                order_id=order_id,
+                **order_submit.kwargs,
+            )
+        else:
+            self._log.error(
+                f"Order ID not found for UUID: {order_submit.uuid}, The order may already be canceled or filled or not exist"
+            )
+
     async def _create_order(
         self, order_submit: CreateOrderSubmit, account_type: AccountType
     ):
         """
         Create an order
         """
-        order: Order = await self._private_connectors[account_type].create_order(
+        order: Order = await self._private_connectors[account_type]._oms.create_order(
+            uuid=order_submit.uuid,
             symbol=order_submit.symbol,
             side=order_submit.side,
             type=order_submit.type,
             amount=order_submit.amount,
             price=order_submit.price,
             time_in_force=order_submit.time_in_force,
-            position_side=order_submit.position_side,
+            reduce_only=order_submit.reduce_only,
+            # position_side=order_submit.position_side,
             **order_submit.kwargs,
         )
-        order.uuid = order_submit.uuid
         if order.success:
             self._cache._order_initialized(order)  # INITIALIZED -> PENDING
             self._msgbus.send(endpoint="pending", msg=order)
@@ -244,65 +272,24 @@ class ExecutionManagementSystem(ABC):
             self._msgbus.send(endpoint="failed", msg=order)
         return order
 
-    async def _create_stop_loss_order(
-        self, order_submit: TakeProfitAndStopLossOrderSubmit, account_type: AccountType
+    async def _create_order_ws(
+        self, order_submit: CreateOrderSubmit, account_type: AccountType
     ):
         """
-        Create a stop loss order
+        Create an order
         """
-        order: Order = await self._private_connectors[
-            account_type
-        ].create_stop_loss_order(
+        await self._private_connectors[account_type]._oms.create_order_ws(
+            uuid=order_submit.uuid,
             symbol=order_submit.symbol,
             side=order_submit.side,
             type=order_submit.type,
             amount=order_submit.amount,
-            trigger_type=order_submit.trigger_type,
-            trigger_price=order_submit.trigger_price,
             price=order_submit.price,
             time_in_force=order_submit.time_in_force,
-            position_side=order_submit.position_side,
+            reduce_only=order_submit.reduce_only,
+            # position_side=order_submit.position_side,
             **order_submit.kwargs,
         )
-        order.uuid = order_submit.uuid
-        if order.success:
-            self._registry.register_order(order)
-            self._cache._order_initialized(order)  # INITIALIZED -> PENDING
-            self._msgbus.send(endpoint="pending", msg=order)
-        else:
-            self._cache._order_status_update(order)  # INITIALIZED -> FAILED
-            self._msgbus.send(endpoint="failed", msg=order)
-        return order
-
-    async def _create_take_profit_order(
-        self, order_submit: TakeProfitAndStopLossOrderSubmit, account_type: AccountType
-    ) -> Order:
-        """
-        Create a take profit order
-        """
-        order: Order = await self._private_connectors[
-            account_type
-        ].create_take_profit_order(
-            symbol=order_submit.symbol,
-            side=order_submit.side,
-            type=order_submit.type,
-            amount=order_submit.amount,
-            trigger_price=order_submit.trigger_price,
-            trigger_type=order_submit.trigger_type,
-            price=order_submit.price,
-            time_in_force=order_submit.time_in_force,
-            position_side=order_submit.position_side,
-            **order_submit.kwargs,
-        )
-        order.uuid = order_submit.uuid
-        if order.success:
-            self._registry.register_order(order)
-            self._cache._order_initialized(order)  # INITIALIZED -> PENDING
-            self._msgbus.send(endpoint="pending", msg=order)
-        else:
-            self._cache._order_status_update(order)  # INITIALIZED -> FAILED
-            self._msgbus.send(endpoint="failed", msg=order)
-        return order
 
     @abstractmethod
     def _get_min_order_amount(self, symbol: str, market: BaseMarket) -> Decimal:
@@ -597,8 +584,40 @@ class ExecutionManagementSystem(ABC):
         uuid = order_submit.uuid
         self._task_manager.cancel_task(uuid)
 
+    async def _create_tp_sl_order(
+        self, order_submit: TakeProfitAndStopLossOrderSubmit, account_type: AccountType
+    ):
+        order: Order = await self._private_connectors[
+            account_type
+        ]._oms.create_tp_sl_order(
+            uuid=order_submit.uuid,
+            symbol=order_submit.symbol,
+            side=order_submit.side,
+            type=order_submit.type,
+            amount=order_submit.amount,
+            price=order_submit.price,
+            time_in_force=order_submit.time_in_force,
+            tp_order_type=order_submit.tp_order_type,
+            tp_trigger_price=order_submit.tp_trigger_price,
+            tp_price=order_submit.tp_price,
+            tp_trigger_type=order_submit.tp_trigger_type,
+            sl_order_type=order_submit.sl_order_type,
+            sl_trigger_price=order_submit.sl_trigger_price,
+            sl_price=order_submit.sl_price,
+            sl_trigger_type=order_submit.sl_trigger_type,
+            **order_submit.kwargs,
+        )
+        if order.success:
+            self._cache._order_initialized(order)  # INITIALIZED -> PENDING
+            self._msgbus.send(endpoint="pending", msg=order)
+            self._registry.register_order(order)
+        else:
+            self._cache._order_status_update(order)  # INITIALIZED -> FAILED
+            self._msgbus.send(endpoint="failed", msg=order)
+        return order
+
     async def _handle_submit_order(
-        self, account_type: AccountType, queue: asyncio.Queue[OrderSubmit]
+        self, account_type: AccountType, queue: asyncio.Queue[(OrderSubmit, SubmitType)]
     ):
         """
         Handle the order submit
@@ -608,20 +627,40 @@ class ExecutionManagementSystem(ABC):
             SubmitType.CREATE: self._create_order,
             SubmitType.TWAP: self._create_twap_order,
             SubmitType.CANCEL_TWAP: self._cancel_twap_order,
-            SubmitType.STOP_LOSS: self._create_stop_loss_order,
-            SubmitType.TAKE_PROFIT: self._create_take_profit_order,
             SubmitType.MODIFY: self._modify_order,
             SubmitType.CANCEL_ALL: self._cancel_all_orders,
+            SubmitType.BATCH: self._create_batch_orders,
+            SubmitType.TAKE_PROFIT_AND_STOP_LOSS: self._create_tp_sl_order,
+            SubmitType.CREATE_WS: self._create_order_ws,
+            SubmitType.CANCEL_WS: self._cancel_order_ws,
         }
 
         self._log.debug(f"Handling orders for account type: {account_type}")
         while True:
-            order_submit = await queue.get()
+            (order_submit, submit_type) = await queue.get()
             self._log.debug(f"[ORDER SUBMIT]: {order_submit}")
-            handler = submit_handlers[order_submit.submit_type]
+            handler = submit_handlers[submit_type]
             await handler(order_submit, account_type)
             queue.task_done()
 
+    async def _create_batch_orders(
+        self, batch_orders: List[BatchOrderSubmit], account_type: AccountType
+    ):
+        orders: List[Order] = await self._private_connectors[
+            account_type
+        ]._oms.create_batch_orders(
+            orders=batch_orders,
+        )
+        for order in orders:
+            if order.success:
+                self._cache._order_initialized(order)  # INITIALIZED -> PENDING
+                self._msgbus.send(endpoint="pending", msg=order)
+                self._registry.register_order(order)
+            else:
+                self._cache._order_status_update(order)
+                self._msgbus.send(endpoint="failed", msg=order)
+        return orders
+
     async def start(self):
         """
         Start the order submit
