@@ -1,6 +1,8 @@
 import msgspec
 from typing import Dict, List
 from decimal import Decimal
+from typing import Literal
+from decimal import ROUND_HALF_UP, ROUND_CEILING, ROUND_FLOOR
 from nexustrader.error import PositionModeError
 from nexustrader.core.nautilius_core import LiveClock, MessageBus
 from nexustrader.core.cache import AsyncCache
@@ -35,7 +37,6 @@ from nexustrader.exchange.bitget.schema import (
     BitgetWsApiGeneralMsg,
     BitgetWsApiArgMsg,
     BitgetWsApiUtaGeneralMsg,
-    BitgetWsApiUtaArgMsg,
 )
 from nexustrader.exchange.bitget.rest_api import BitgetApiClient
 from nexustrader.exchange.bitget.websockets import BitgetWSClient, BitgetWSApiClient
@@ -178,12 +179,10 @@ class BitgetOrderManagementSystem(OrderManagementSystem):
     def _handle_id_messages(self, ws_msg: BitgetWsApiUtaGeneralMsg):
         """Handle argument messages for place and cancel orders"""
         uuid = ws_msg.id
-
-        for arg_msg in ws_msg.args:
-            if not self._registry.get_order_id(uuid=uuid):
-                self._handle_uta_place_order_response(ws_msg, arg_msg)
-            else:
-                self._handle_uta_cancel_order_response(ws_msg, arg_msg)
+        if not self._registry.get_order_id(uuid=uuid):
+            self._handle_uta_place_order_response(ws_msg)
+        else:
+            self._handle_uta_cancel_order_response(ws_msg)
 
     def _handle_arg_messages(self, ws_msg: BitgetWsApiGeneralMsg):
         """Handle argument messages for place and cancel orders"""
@@ -193,24 +192,23 @@ class BitgetOrderManagementSystem(OrderManagementSystem):
             elif arg_msg.is_cancel_order:
                 self._handle_cancel_order_response(ws_msg, arg_msg)
 
-    def _handle_uta_place_order_response(
-        self, ws_msg: BitgetWsApiUtaGeneralMsg, arg_msg: BitgetWsApiUtaArgMsg
-    ):
+    def _handle_uta_place_order_response(self, ws_msg: BitgetWsApiUtaGeneralMsg):
         uuid = ws_msg.id
         tmp_order = self._registry.get_tmp_order(uuid)
         ts = self._clock.timestamp_ms()
 
         if ws_msg.is_success:
-            ordId = arg_msg.orderId
-            self._log.debug(
-                f"[{tmp_order.symbol}] placing order success: uuid: {uuid} id: {ordId}"
-            )
-            order = self._create_order_from_tmp(
-                tmp_order, uuid, ordId, OrderStatus.PENDING, ts
-            )
-            self._cache._order_initialized(order)  # INITIALIZED -> PENDING
-            self._msgbus.send(endpoint="pending", msg=order)
-            self._registry.register_order(order)
+            for arg_msg in ws_msg.args:
+                ordId = arg_msg.orderId
+                self._log.debug(
+                    f"[{tmp_order.symbol}] placing order success: uuid: {uuid} id: {ordId}"
+                )
+                order = self._create_order_from_tmp(
+                    tmp_order, uuid, ordId, OrderStatus.PENDING, ts
+                )
+                self._cache._order_initialized(order)  # INITIALIZED -> PENDING
+                self._msgbus.send(endpoint="pending", msg=order)
+                self._registry.register_order(order)
         else:
             self._log.error(
                 f"[{tmp_order.symbol}] new order failed: uuid: {uuid} {ws_msg.error_msg}"
@@ -221,24 +219,23 @@ class BitgetOrderManagementSystem(OrderManagementSystem):
             self._cache._order_status_update(order)  # INITIALIZED -> FAILED
             self._msgbus.send(endpoint="failed", msg=order)
 
-    def _handle_uta_cancel_order_response(
-        self, ws_msg: BitgetWsApiUtaGeneralMsg, arg_msg: BitgetWsApiUtaArgMsg
-    ):
+    def _handle_uta_cancel_order_response(self, ws_msg: BitgetWsApiUtaGeneralMsg):
         """Handle cancel order response"""
         uuid = ws_msg.id
         tmp_order = self._registry.get_tmp_order(uuid)
         ts = self._clock.timestamp_ms()
 
         if ws_msg.is_success:
-            ordId = arg_msg.orderId
-            self._log.debug(
-                f"[{tmp_order.symbol}] canceling order success: uuid: {uuid} id: {ordId}"
-            )
-            order = self._create_order_from_tmp(
-                tmp_order, uuid, ordId, OrderStatus.CANCELING, ts
-            )
-            self._cache._order_status_update(order)  # SOME STATUS -> CANCELING
-            self._msgbus.send(endpoint="canceling", msg=order)
+            for arg_msg in ws_msg.args:
+                ordId = arg_msg.orderId
+                self._log.debug(
+                    f"[{tmp_order.symbol}] canceling order success: uuid: {uuid} id: {ordId}"
+                )
+                order = self._create_order_from_tmp(
+                    tmp_order, uuid, ordId, OrderStatus.CANCELING, ts
+                )
+                self._cache._order_status_update(order)  # SOME STATUS -> CANCELING
+                self._msgbus.send(endpoint="canceling", msg=order)
         else:
             self._log.error(
                 f"[{tmp_order.symbol}] canceling order failed: uuid: {uuid} {ws_msg.error_msg}"
@@ -354,7 +351,73 @@ class BitgetOrderManagementSystem(OrderManagementSystem):
         # Bitget has different product types for different instrument types
 
         if self._account_type.is_uta:
-            pass
+            # For UTA accounts, use the v3 position API
+            categories = ["USDT-FUTURES", "USDC-FUTURES", "COIN-FUTURES"]
+
+            for category in categories:
+                response = self._api_client.get_api_v3_position_current_position(
+                    category=category
+                )
+
+                if not response.data.list:
+                    continue
+
+                for pos_data in response.data.list:
+                    # Skip positions with zero total
+                    if float(pos_data.total) == 0:
+                        continue
+
+                    # Check position mode - only support one-way mode for UTA
+                    if pos_data.holdMode != "one_way_mode":
+                        raise PositionModeError(
+                            f"Only one-way mode is supported for UTA accounts. Current mode: {pos_data.holdMode}"
+                        )
+
+                    # Determine suffix based on category
+                    if category == "USDT-FUTURES":
+                        inst_type_suffix = "linear"
+                    elif category == "USDC-FUTURES":
+                        inst_type_suffix = "linear"
+                    elif category == "COIN-FUTURES":
+                        inst_type_suffix = "inverse"
+
+                    # Map symbol from Bitget format to our internal format
+                    symbol = self._market_id.get(
+                        f"{pos_data.symbol}_{inst_type_suffix}"
+                    )
+
+                    if not symbol:
+                        self._log.warning(
+                            f"Symbol {pos_data.symbol} not found in market mapping"
+                        )
+                        continue
+
+                    # Convert position side string to BitgetPositionSide enum
+                    hold_side = BitgetPositionSide(pos_data.posSide)
+
+                    # Convert to signed amount based on position side
+                    signed_amount = Decimal(pos_data.total)
+                    if hold_side == BitgetPositionSide.SHORT:
+                        signed_amount = -signed_amount
+
+                    # Parse position side
+                    position_side = hold_side.parse_to_position_side()
+
+                    # Create Position object
+                    position = Position(
+                        symbol=symbol,
+                        exchange=self._exchange_id,
+                        signed_amount=signed_amount,
+                        entry_price=float(pos_data.avgPrice),
+                        side=position_side,
+                        unrealized_pnl=float(pos_data.unrealisedPnl),
+                        realized_pnl=float(pos_data.curRealisedPnl),
+                    )
+
+                    # Apply position to cache
+                    self._cache._apply_position(position)
+                    self._log.debug(f"Initialized UTA position: {str(position)}")
+
         else:
             product_types = ["USDT-FUTURES", "USDC-FUTURES", "COIN-FUTURES"]
 
@@ -442,6 +505,34 @@ class BitgetOrderManagementSystem(OrderManagementSystem):
         """Create a take profit and stop loss order"""
         raise NotImplementedError
 
+    def _price_to_precision(
+        self,
+        symbol: str,
+        price: float,
+        mode: Literal["round", "ceil", "floor"] = "round",
+    ) -> Decimal:
+        market = self._market[symbol]
+        if market.spot:
+            return super()._price_to_precision(symbol, price, mode)
+        else:
+            price: Decimal = Decimal(str(price))
+            price_multiplier = Decimal(market.info.priceEndStep)
+            multiplier_count = price / price_multiplier
+
+            if mode == "round":
+                price = (
+                    multiplier_count.quantize(Decimal("1"), rounding=ROUND_HALF_UP)
+                ) * price_multiplier
+            elif mode == "ceil":
+                price = (
+                    multiplier_count.quantize(Decimal("1"), rounding=ROUND_CEILING)
+                ) * price_multiplier
+            elif mode == "floor":
+                price = (
+                    multiplier_count.quantize(Decimal("1"), rounding=ROUND_FLOOR)
+                ) * price_multiplier
+            return price
+
     async def create_order_ws(
         self,
         uuid: str,
