@@ -317,6 +317,14 @@ class Order(Struct):
     def is_filled(self) -> bool:
         return self.status == OrderStatus.FILLED
 
+    @property
+    def is_pending(self) -> bool:
+        return self.status == OrderStatus.PENDING
+
+    @property
+    def is_accepted(self) -> bool:
+        return self.status == OrderStatus.ACCEPTED
+
     @property
     def is_partially_filled(self) -> bool:
         return self.status == OrderStatus.PARTIALLY_FILLED
